==> use-async-call-2.0.1.tgz: package/dist-web/index.js <==
import { useEffect, useCallback } from 'react';
import useAsyncReducer from 'use-async-reducer';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

function getUpdaterPromise(asyncUpdater) {
  if (typeof asyncUpdater === 'function') {
    return asyncUpdater();
  }

  return asyncUpdater;
}

function useAsyncCall(asyncCreator) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  const _useAsyncReducer = useAsyncReducer(options.initialValue),
        _useAsyncReducer2 = _slicedToArray(_useAsyncReducer, 2),
        response = _useAsyncReducer2[0],
        actions = _useAsyncReducer2[1];

  useEffect(() => {
    let didCancel = false;

    const callAsync =
    /*#__PURE__*/
    function () {
      var _ref = _asyncToGenerator(function* () {
        actions.request();

        try {
          const data = yield asyncCreator();

          if (didCancel) {
            return;
          }

          actions.success(data);

          if (typeof options.onSuccess === 'function') {
            options.onSuccess(data);
          }
        } catch (error) {
          if (didCancel) {
            return;
          }

          actions.failure(error);

          if (typeof options.onFailure === 'function') {
            options.onFailure(error);
          }
        } finally {
          if (didCancel) {
            return;
          }

          if (typeof options.onComplete === 'function') {
            options.onComplete();
          }
        }
      });

      return function callAsync() {
        return _ref.apply(this, arguments);
      };
    }();

    callAsync();
    return () => {
      didCancel = true;
    };
  }, [asyncCreator, options.onSuccess, options.onFailure, options.onComplete]);
  const update = useCallback(
  /*#__PURE__*/
  function () {
    var _ref2 = _asyncToGenerator(function* (asyncUpdater) {
      let updateOptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      actions.request();

      try {
        const data = yield getUpdaterPromise(asyncUpdater);

        actions.success(data);

        if (typeof updateOptions.onSuccess === 'function') {
          updateOptions.onSuccess(data);
        }

        return data;
      } catch (error) {

        if (updateOptions.saveError) {
          actions.failure(error);
        } else {
          actions.complete();
        }

        if (typeof updateOptions.onFailure === 'function') {
          updateOptions.onFailure(error);
        }

        if (updateOptions.throwError) {
          throw error;
        }
      } finally {

        if (typeof updateOptions.onComplete === 'function') {
          updateOptions.onComplete();
        }
      }
    });

    return function (_x) {
      return _ref2.apply(this, arguments);
    };
  }(), [actions]);
  return [response, update];
}

export default useAsyncCall;

==> use-async-call-2.1.0.tgz: package/dist-web/index.js <==
import { useEffect, useCallback, useState } from 'react';
import useAsyncReducer from 'use-async-reducer';

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

function getUpdaterPromise(asyncUpdater) {
  if (typeof asyncUpdater === 'function') {
    return asyncUpdater();
  }

  return asyncUpdater;
}

function useRefreshSymbol() {
  const _useState = useState(() => Symbol()),
        _useState2 = _slicedToArray(_useState, 2),
        refreshSymbol = _useState2[0],
        setRefreshSymbol = _useState2[1];

  const updateSymbol = useCallback(() => {
    setRefreshSymbol(Symbol());
  }, [setRefreshSymbol]);
  return [refreshSymbol, updateSymbol];
}
/**
 * Provides an abstraction to manage async state
 * @param asyncCreator Async method to call, create this method with `useCallback` if it uses state from the component
 * @param options
 */


function useAsyncCall(asyncCreator) {
  let options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  const _useRefreshSymbol = useRefreshSymbol(),
        _useRefreshSymbol2 = _slicedToArray(_useRefreshSymbol, 2),
        refreshSymbol = _useRefreshSymbol2[0],
        refresh = _useRefreshSymbol2[1];

  const _useAsyncReducer = useAsyncReducer(options.initialValue),
        _useAsyncReducer2 = _slicedToArray(_useAsyncReducer, 2),
        response = _useAsyncReducer2[0],
        actions = _useAsyncReducer2[1];

  useEffect(() => {
    let didCancel = false;

    const callAsync =
    /*#__PURE__*/
    function () {
      var _ref = _asyncToGenerator(function* () {
        actions.request();

        try {
          const data = yield asyncCreator();

          if (didCancel) {
            return;
          }

          actions.success(data);

          if (typeof options.onSuccess === 'function') {
            options.onSuccess(data);
          }
        } catch (error) {
          if (didCancel) {
            return;
          }

          actions.failure(error);

          if (typeof options.onFailure === 'function') {
            options.onFailure(error);
          }
        } finally {
          if (didCancel) {
            return;
          }

          if (typeof options.onComplete === 'function') {
            options.onComplete();
          }
        }
      });

      return function callAsync() {
        return _ref.apply(this, arguments);
      };
    }();

    callAsync();
    return () => {
      didCancel = true;
    };
  }, [asyncCreator, options.onSuccess, options.onFailure, options.onComplete, refreshSymbol]);
  const update = useCallback(
  /*#__PURE__*/
  function () {
    var _ref2 = _asyncToGenerator(function* (asyncUpdater) {
      let updateOptions = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
      actions.request();

      try {
        const data = yield getUpdaterPromise(asyncUpdater);
        actions.success(data);

        if (typeof updateOptions.onSuccess === 'function') {
          updateOptions.onSuccess(data);
        }

        return data;
      } catch (error) {
        if (updateOptions.saveError) {
          actions.failure(error);
        } else {
          actions.complete();
        }

        if (typeof updateOptions.onFailure === 'function') {
          updateOptions.onFailure(error);
        }

        if (updateOptions.throwError) {
          throw error;
        }
      } finally {
        if (typeof updateOptions.onComplete === 'function') {
          updateOptions.onComplete();
        }
      }
    });

    return function (_x) {
      return _ref2.apply(this, arguments);
    };
  }(), [actions]);
  return [response, update, refresh];
}

export default useAsyncCall;
